@@ -9,7 +9,6 @@ import rich_click as click
 
 import in2lambda.filters
 from in2lambda.api.module import Module
-from in2lambda.json_convert import json_convert
 
 
 def file_type(file: str) -> str:
@@ -40,7 +39,17 @@ def file_type(file: str) -> str:
     match (extension := file.split(".")[-1].lower()):
         case "tex" | "latex" | "ltx":
             return "latex"
-        case "md" | "rmd" | "markdown" | "mdown" | "mdwn" | "mkd" | "mkdn" | "text" | "txt":
+        case (
+            "md"
+            | "rmd"
+            | "markdown"
+            | "mdown"
+            | "mdwn"
+            | "mkd"
+            | "mkdn"
+            | "text"
+            | "txt"
+        ):
             return "markdown"
         case "docx":
             return "docx"  # Pandoc doesn't seem to support doc
@@ -71,9 +80,9 @@ def runner(
         >>> from in2lambda.main import runner
         >>> # Retrieve an example TeX file and run the given filter.
         >>> runner(f"{os.path.dirname(in2lambda.__file__)}/filters/PartsSepSol/example.tex", "PartsSepSol") # doctest: +ELLIPSIS
-        Module(questions=[Question(title='', parts=[Part(text=..., worked_solution=''), ...], images=[], _main_text='This is a sample question\n\n'), ...])
+        Module(questions=[Question(title='', parts=[Part(text=..., worked_solution=''), ...], images=[], main_text='This is a sample question\n\n'), ...])
         >>> runner(f"{os.path.dirname(in2lambda.__file__)}/filters/PartsOneSol/example.tex", "PartsOneSol") # doctest: +ELLIPSIS
-        Module(questions=[Question(title='', parts=[Part(text='This is part (a)\n\n', worked_solution=''), ...], images=[], _main_text='Here is some preliminary question information that might be useful.'), ...)
+        Module(questions=[Question(title='', parts=[Part(text='This is part (a)\n\n', worked_solution=''), ...], images=[], main_text='Here is some preliminary question information that might be useful.'), ...)
     """
     # The list of questions for Lambda Feedback as a Python API.
     module = Module()
@@ -112,7 +121,7 @@ def runner(
 
     # Read the Python API format and convert to JSON.
     if output_dir is not None:
-        json_convert.main(module.questions, output_dir)
+        module.to_json(output_dir)
 
     return module
 
